@@ -7,6 +7,7 @@ import collections
 import requests
 import uuid
 import json
+import random
 
 # To run the standalone test script
 if __name__ == '__main__':
@@ -65,6 +66,7 @@ class KongAdminTesting(object):
             self.client = self.on_create_client()
             self.assertTrue(self.client.apis.count() == 0)
             self._cleanup = []
+            fake.seed(random.randint(1000, 10000000))
 
         def tearDown(self):
             for name_or_id in set(self._cleanup):
@@ -76,13 +78,13 @@ class KongAdminTesting(object):
             name = fake.api_name()
             dns = fake.domain_name()
 
-            result = self.client.apis.add(target_url=url, name=name, public_dns=dns)
+            result = self.client.apis.add(upstream_url=url, name=name, inbound_dns=dns)
             self._cleanup_afterwards(result['id'])
 
             self.assertEqual(self.client.apis.count(), 1)
-            self.assertEqual(result['target_url'], url)
+            self.assertEqual(result['upstream_url'], url)
             self.assertEqual(result['name'], name)
-            self.assertEqual(result['public_dns'], dns)
+            self.assertEqual(result['inbound_dns'], dns)
             self.assertIsNotNone(result['id'])
             self.assertIsNotNone(result['created_at'])
             self.assertFalse('path' in result)
@@ -93,15 +95,14 @@ class KongAdminTesting(object):
             dns = fake.domain_name()
 
             result = self.client.apis.add(
-                target_url=url, name=name, public_dns=dns, strip_path=True, preserve_host=True)
+                upstream_url=url, name=name, inbound_dns=dns, strip_path=True)
             self._cleanup_afterwards(result['id'])
 
             self.assertEqual(self.client.apis.count(), 1)
-            self.assertEqual(result['target_url'], url)
+            self.assertEqual(result['upstream_url'], url)
             self.assertEqual(result['name'], name)
-            self.assertEqual(result['public_dns'], dns)
+            self.assertEqual(result['inbound_dns'], dns)
             self.assertTrue(result['strip_path'])
-            self.assertTrue(result['preserve_host'])
             self.assertIsNotNone(result['id'])
             self.assertIsNotNone(result['created_at'])
             self.assertFalse('path' in result)
@@ -111,7 +112,7 @@ class KongAdminTesting(object):
             name = fake.api_name()
             dns = fake.domain_name()
 
-            result = self.client.apis.add(target_url=url, name=name, public_dns=dns)
+            result = self.client.apis.add(upstream_url=url, name=name, inbound_dns=dns)
             self._cleanup_afterwards(result['id'])
 
             self.assertEqual(self.client.apis.count(), 1)
@@ -119,7 +120,7 @@ class KongAdminTesting(object):
             result2 = None
             error_thrown = False
             try:
-                result2 = self.client.apis.add(target_url=fake.url(), name=name, public_dns=fake.domain_name())
+                result2 = self.client.apis.add(upstream_url=fake.url(), name=name, inbound_dns=fake.domain_name())
             except ConflictError:
                 error_thrown = True
             self.assertTrue(error_thrown)
@@ -132,7 +133,7 @@ class KongAdminTesting(object):
             name = fake.api_name()
             dns = fake.domain_name()
 
-            result = self.client.apis.add(target_url=url, name=name, public_dns=dns)
+            result = self.client.apis.add(upstream_url=url, name=name, inbound_dns=dns)
             self._cleanup_afterwards(result['id'])
 
             self.assertEqual(self.client.apis.count(), 1)
@@ -140,7 +141,7 @@ class KongAdminTesting(object):
             result2 = None
             error_thrown = False
             try:
-                result2 = self.client.apis.add(target_url=fake.url(), name=fake.api_name(), public_dns=dns)
+                result2 = self.client.apis.add(upstream_url=fake.url(), name=fake.api_name(), inbound_dns=dns)
             except ConflictError:
                 error_thrown = True
             self.assertTrue(error_thrown)
@@ -151,18 +152,18 @@ class KongAdminTesting(object):
         def test_add_missing_public_dns_and_path(self):
             result = None
             with self.assertRaises(ValueError):
-                result = self.client.apis.add(target_url=fake.url())
+                result = self.client.apis.add(upstream_url=fake.url())
             self.assertIsNone(result)
             self.assertEqual(self.client.apis.count(), 0)
 
         def test_add_missing_public_dns(self):
-            result = self.client.apis.add(target_url=fake.url(), path=fake.api_path())
+            result = self.client.apis.add(upstream_url=fake.url(), path=fake.api_path())
             self.assertIsNotNone(result)
             self._cleanup_afterwards(result['id']),
             self.assertEqual(self.client.apis.count(), 1)
 
         def test_add_missing_path(self):
-            result = self.client.apis.add(target_url=fake.url(), public_dns=fake.domain_name())
+            result = self.client.apis.add(upstream_url=fake.url(), inbound_dns=fake.domain_name())
             self.assertIsNotNone(result)
             self._cleanup_afterwards(result['id']),
             self.assertEqual(self.client.apis.count(), 1)
@@ -172,7 +173,7 @@ class KongAdminTesting(object):
             name = fake.api_name()
             dns = fake.domain_name()
 
-            result = self.client.apis.add(target_url=url, name=name, public_dns=dns)
+            result = self.client.apis.add(upstream_url=url, name=name, inbound_dns=dns)
             self._cleanup_afterwards(result['id']),
 
             # Update by name
@@ -180,43 +181,43 @@ class KongAdminTesting(object):
             result2 = self.client.apis.update(name, url, path=new_path, strip_path=True)
             self.assertEqual(result2['id'], result['id'])
             self.assertEqual(result2['path'], new_path)
-            self.assertEqual(result2['public_dns'], dns)
+            self.assertEqual(result2['inbound_dns'], dns)
             self.assertTrue(result2['strip_path'])
 
             # Update by id
             new_path = fake.api_path()
             new_url = fake.url()
             new_dns = fake.domain_name()
-            result3 = self.client.apis.update(result['id'], new_url, path=new_path, public_dns=new_dns)
+            result3 = self.client.apis.update(result['id'], new_url, path=new_path, inbound_dns=new_dns)
             self.assertEqual(result3['id'], result['id'])
-            self.assertEqual(result3['target_url'], new_url)
+            self.assertEqual(result3['upstream_url'], new_url)
             self.assertEqual(result3['path'], new_path)
-            self.assertEqual(result3['public_dns'], new_dns)
+            self.assertEqual(result3['inbound_dns'], new_dns)
             self.assertTrue(result3['strip_path'])
 
             # retrieve to check
             result4 = self.client.apis.retrieve(result['id'])
             self.assertIsNotNone(result4)
             self.assertEqual(result4['id'], result['id'])
-            self.assertEqual(result4['target_url'], new_url)
+            self.assertEqual(result4['upstream_url'], new_url)
             self.assertEqual(result4['path'], new_path)
-            self.assertEqual(result4['public_dns'], new_dns)
+            self.assertEqual(result4['inbound_dns'], new_dns)
             self.assertTrue(result4['strip_path'])
 
         def test_add_or_update(self):
-            result = self.client.apis.add(target_url=fake.url(), name=fake.api_name(), public_dns=fake.domain_name())
+            result = self.client.apis.add(upstream_url=fake.url(), name=fake.api_name(), inbound_dns=fake.domain_name())
             self._cleanup_afterwards(result['id'])
             self.assertEqual(self.client.apis.count(), 1)
 
             # Test add_or_update without api_id -> Should ADD
             result2 = self.client.apis.add_or_update(
-                target_url=fake.url(), name=fake.api_name(), public_dns=fake.domain_name())
+                upstream_url=fake.url(), name=fake.api_name(), inbound_dns=fake.domain_name())
             self._cleanup_afterwards(result2['id'])
             self.assertEqual(self.client.apis.count(), 2)
 
             # Test add_or_update with api_id -> Should UPDATE
             result3 = self.client.apis.add_or_update(
-                target_url=fake.url(), api_id=result['id'], name=fake.api_name(), public_dns=fake.domain_name())
+                upstream_url=fake.url(), api_id=result['id'], name=fake.api_name(), inbound_dns=fake.domain_name())
             self._cleanup_afterwards(result3['id'])
             self.assertEqual(self.client.apis.count(), 2)
             self.assertEqual(result3['id'], result['id'])
@@ -226,12 +227,12 @@ class KongAdminTesting(object):
             name = fake.api_name()
             dns = fake.domain_name()
 
-            result = self.client.apis.add(target_url=url, name=name, public_dns=dns)
+            result = self.client.apis.add(upstream_url=url, name=name, inbound_dns=dns)
             self._cleanup_afterwards(result['id'])
 
-            self.assertEqual(result['target_url'], url)
+            self.assertEqual(result['upstream_url'], url)
             self.assertEqual(result['name'], name)
-            self.assertEqual(result['public_dns'], dns)
+            self.assertEqual(result['inbound_dns'], dns)
 
             # Retrieve by name
             result2 = self.client.apis.retrieve(name)
@@ -247,7 +248,7 @@ class KongAdminTesting(object):
 
             dns_list = [fake.domain_name() for i in range(amount)]
             for i in range(amount):
-                result = self.client.apis.add(target_url=fake.url(), name=fake.api_name(), public_dns=dns_list[i])
+                result = self.client.apis.add(upstream_url=fake.url(), name=fake.api_name(), inbound_dns=dns_list[i])
                 self._cleanup_afterwards(result['id'])
 
             self.assertEqual(self.client.apis.count(), amount)
@@ -258,7 +259,7 @@ class KongAdminTesting(object):
 
             self.assertEqual(len(data), amount)
 
-            result = self.client.apis.list(public_dns=dns_list[4])
+            result = self.client.apis.list(inbound_dns=dns_list[4])
             self.assertTrue('data' in result)
             data = result['data']
 
@@ -273,7 +274,7 @@ class KongAdminTesting(object):
 
             for i in range(amount):
                 result = self.client.apis.add(
-                    target_url=fake.url(), name=fake.api_name(), public_dns=fake.domain_name())
+                    upstream_url=fake.url(), name=fake.api_name(), inbound_dns=fake.domain_name())
                 self._cleanup_afterwards(result['id'])
 
             found = []
@@ -291,7 +292,7 @@ class KongAdminTesting(object):
 
             api_names = [fake.api_name() for i in range(amount)]
             for i in range(amount):
-                result = self.client.apis.add(target_url=fake.url(), name=api_names[i], public_dns=fake.domain_name())
+                result = self.client.apis.add(upstream_url=fake.url(), name=api_names[i], inbound_dns=fake.domain_name())
                 self._cleanup_afterwards(result['id'])
 
             found = []
@@ -308,11 +309,11 @@ class KongAdminTesting(object):
             url1 = fake.url()
             url2 = fake.url()
 
-            result1 = self.client.apis.add(target_url=url1, name=fake.api_name(), public_dns=fake.domain_name())
-            self.assertEqual(result1['target_url'], url1)
+            result1 = self.client.apis.add(upstream_url=url1, name=fake.api_name(), inbound_dns=fake.domain_name())
+            self.assertEqual(result1['upstream_url'], url1)
 
-            result2 = self.client.apis.add(target_url=url2, name=fake.api_name(), public_dns=fake.domain_name())
-            self.assertEqual(result2['target_url'], url2)
+            result2 = self.client.apis.add(upstream_url=url2, name=fake.api_name(), inbound_dns=fake.domain_name())
+            self.assertEqual(result2['upstream_url'], url2)
 
             self.assertEqual(self.client.apis.count(), 2)
 
@@ -327,35 +328,35 @@ class KongAdminTesting(object):
         def test_create_global_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
             # Create global plugin configuration for the api
-            result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins('Mockbin').create('rate-limiting', enabled=False, second=20)
             self.assertIsNotNone(result2)
             self.assertIsNotNone(result2['id'])
             self.assertIsNotNone(result2['api_id'])
             self.assertFalse(result2['enabled'])
-            self.assertEqual(result2['value']['second'], 20)
+            self.assertEqual(result2['config']['second'], 20)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 1)
 
         def test_create_plugin_configuration_conflict(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
             # Create global plugin configuration for the api
-            result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins('Mockbin').create('rate-limiting', enabled=False, second=20)
             self.assertIsNotNone(result2)
             self.assertIsNotNone(result2['id'])
 
             result3 = None
             error_thrown = False
             try:
-                result3 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=35)
+                result3 = self.client.apis.plugins('Mockbin').create('rate-limiting', enabled=False, second=35)
             except ConflictError as e:
                 error_thrown = True
             self.assertTrue(error_thrown)
@@ -364,7 +365,7 @@ class KongAdminTesting(object):
         def test_create_non_existing_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
@@ -380,14 +381,14 @@ class KongAdminTesting(object):
         def test_create_incorrect_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
             result2 = None
             error_thrown = False
             try:
-                result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', unknown_parameter=20)
+                result2 = self.client.apis.plugins('Mockbin').create('rate-limiting', unknown_parameter=20)
             except ValueError:
                 error_thrown = True
             self.assertTrue(error_thrown)
@@ -396,7 +397,7 @@ class KongAdminTesting(object):
         def test_create_consumer_specific_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
@@ -406,7 +407,7 @@ class KongAdminTesting(object):
             try:
                 # Create consumer specific plugin configuration for the api
                 result2 = self.client.apis.plugins('Mockbin').create(
-                    'requestsizelimiting', consumer_id=consumer['id'], allowed_payload_size=512)
+                    'request-size-limiting', consumer_id=consumer['id'], allowed_payload_size=512)
                 self.assertIsNotNone(result2)
                 self.assertIsNotNone(result2['consumer_id'])
                 self.assertEqual(result2['consumer_id'], consumer['id'])
@@ -418,21 +419,21 @@ class KongAdminTesting(object):
         def test_update_global_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
             # Create global plugin configuration for the api
-            result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins('Mockbin').create('rate-limiting', enabled=False, second=20)
             self.assertIsNotNone(result2)
             self.assertEqual(result2['enabled'], False)
-            self.assertEqual(result2['value']['second'], 20)
+            self.assertEqual(result2['config']['second'], 20)
 
             # Update
-            result3 = self.client.apis.plugins('Mockbin').update(result2['name'], enabled=True, second=27)
+            result3 = self.client.apis.plugins('Mockbin').update(result2['id'], enabled=True, second=27)
             self.assertIsNotNone(result3)
             self.assertEqual(result3['enabled'], True)
-            self.assertEqual(result3['value']['second'], 27)
+            self.assertEqual(result3['config']['second'], 27)
 
             # Make sure we still have only 1 configuration
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 1)
@@ -440,39 +441,39 @@ class KongAdminTesting(object):
         def test_create_or_update_global_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
             # Create global plugin configuration for the api
-            result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins('Mockbin').create('rate-limiting', enabled=False, second=20)
             self.assertIsNotNone(result2)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 1)
 
             # Test create_or_update without plugin_id -> Should CREATE
             result3 = self.client.apis.plugins('Mockbin').create_or_update(
-                'requestsizelimiting', enabled=True, allowed_payload_size=128)
+                'request-size-limiting', enabled=True, allowed_payload_size=128)
             self.assertIsNotNone(result3)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 2)
 
             # Test create_or_update with plugin_configuration_id -> Should UPDATE
             result4 = self.client.apis.plugins('Mockbin').create_or_update(
-                'requestsizelimiting', plugin_configuration_id=result3['id'], allowed_payload_size=512)
+                'request-size-limiting', plugin_configuration_id=result3['id'], allowed_payload_size=512)
             self.assertIsNotNone(result4)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 2)
 
         def test_update_incorrect_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
             # Create global plugin configuration for the api
-            result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins('Mockbin').create('rate-limiting', enabled=False, second=20)
             self.assertIsNotNone(result2)
             self.assertEqual(result2['enabled'], False)
-            self.assertEqual(result2['value']['second'], 20)
+            self.assertEqual(result2['config']['second'], 20)
 
             # Update
             result3 = None
@@ -491,7 +492,7 @@ class KongAdminTesting(object):
         def test_update_consumer_specific_plugin_configuration(self):
             # Create test api
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
@@ -501,7 +502,7 @@ class KongAdminTesting(object):
             try:
                 # Create consumer specific plugin configuration for the api
                 result2 = self.client.apis.plugins('Mockbin').create(
-                    'requestsizelimiting', consumer_id=consumer['id'], allowed_payload_size=512)
+                    'request-size-limiting', consumer_id=consumer['id'], allowed_payload_size=512)
                 self.assertIsNotNone(result2)
                 self.assertIsNotNone(result2['consumer_id'])
                 self.assertEqual(result2['consumer_id'], consumer['id'])
@@ -509,10 +510,10 @@ class KongAdminTesting(object):
 
                 # Update
                 result3 = self.client.apis.plugins('Mockbin').update(
-                    'requestsizelimiting', consumer_id=consumer['id'], allowed_payload_size=1024)
+                    result2['id'], consumer_id=consumer['id'], allowed_payload_size=1024)
                 self.assertIsNotNone(result3)
                 self.assertEqual(result3['enabled'], True)
-                self.assertEqual(result3['value']['allowed_payload_size'], 1024)
+                self.assertEqual(result3['config']['allowed_payload_size'], 1024)
                 self.assertIsNotNone(result3['consumer_id'])
                 self.assertEqual(result3['consumer_id'], consumer['id'])
 
@@ -524,37 +525,29 @@ class KongAdminTesting(object):
 
         def test_delete_plugin_configuration(self):
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
-            result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins('Mockbin').create('request-size-limiting', allowed_payload_size=512)
             self.assertIsNotNone(result2)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 1)
 
-            result3 = self.client.apis.plugins('Mockbin').create('requestsizelimiting', allowed_payload_size=512)
-            self.assertIsNotNone(result3)
-            self.assertEqual(self.client.apis.plugins('Mockbin').count(), 2)
-
-            # delete by name
-            self.client.apis.plugins('Mockbin').delete('ratelimiting')
-            self.assertEqual(self.client.apis.plugins('Mockbin').count(), 1)
-
             # delete by id
-            self.client.apis.plugins('Mockbin').delete(result3['id'])
+            self.client.apis.plugins('Mockbin').delete(result2['id'])
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
         def test_list_plugin_configuration(self):
             result = self.client.apis.add(
-                target_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), public_dns='mockbin.com')
+                upstream_url='http://mockbin.com', name=self._cleanup_afterwards('Mockbin'), inbound_dns='mockbin.com')
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 0)
 
-            result2 = self.client.apis.plugins('Mockbin').create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins('Mockbin').create('rate-limiting', enabled=False, second=20)
             self.assertIsNotNone(result2)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 1)
 
-            result3 = self.client.apis.plugins('Mockbin').create('requestsizelimiting', allowed_payload_size=512)
+            result3 = self.client.apis.plugins('Mockbin').create('request-size-limiting', allowed_payload_size=512)
             self.assertIsNotNone(result3)
             self.assertEqual(self.client.apis.plugins('Mockbin').count(), 2)
 
@@ -563,13 +556,13 @@ class KongAdminTesting(object):
 
             self.assertEqual(len(data), 2)
 
-            result5 = self.client.apis.plugins('Mockbin').list(name='requestsizelimiting')
+            result5 = self.client.apis.plugins('Mockbin').list(name='request-size-limiting')
             data = result5['data']
 
             self.assertEqual(len(data), 1)
 
         def test_retrieve_plugin_configuration(self):
-            result = self.client.apis.add(target_url=fake.url(), name=fake.api_name(), public_dns=fake.domain_name())
+            result = self.client.apis.add(upstream_url=fake.url(), name=fake.api_name(), inbound_dns=fake.domain_name())
             self._cleanup_afterwards(result['id'])
 
             api_id = result['id']
@@ -577,25 +570,17 @@ class KongAdminTesting(object):
             self.assertIsNotNone(result)
             self.assertEqual(self.client.apis.plugins(api_id).count(), 0)
 
-            result2 = self.client.apis.plugins(api_id).create('ratelimiting', enabled=False, second=20)
+            result2 = self.client.apis.plugins(api_id).create('rate-limiting', enabled=False, second=20)
             self.assertIsNotNone(result2)
             self.assertEqual(self.client.apis.plugins(api_id).count(), 1)
 
-            # Retrieve by name
-            result3 = self.client.apis.plugins(api_id).retrieve(result2['name'])
+            # Retrieve by id
+            result3 = self.client.apis.plugins(api_id).retrieve(result2['id'])
             self.assertIsNotNone(result3)
             self.assertEqual(result3['api_id'], api_id)
-            self.assertEqual(result3['name'], 'ratelimiting')
+            self.assertEqual(result3['name'], 'rate-limiting')
             self.assertFalse(result3['enabled'])
-            self.assertEqual(result3['value']['second'], 20)
-
-            # Retrieve by id
-            result4 = self.client.apis.plugins(api_id).retrieve(result2['id'])
-            self.assertIsNotNone(result4)
-            self.assertEqual(result4['api_id'], api_id)
-            self.assertEqual(result4['name'], 'ratelimiting')
-            self.assertFalse(result4['enabled'])
-            self.assertEqual(result4['value']['second'], 20)
+            self.assertEqual(result3['config']['second'], 20)
 
         def _cleanup_afterwards(self, name_or_id):
             self._cleanup.append(name_or_id)
@@ -608,6 +593,7 @@ class KongAdminTesting(object):
             self.client = self.on_create_client()
             self.assertTrue(self.client.consumers.count() == 0)
             self._cleanup = []
+            fake.seed(random.randint(1000, 10000000))
 
         def tearDown(self):
             for consumer_username_or_id in set(self._cleanup):
@@ -1240,6 +1226,7 @@ class KongAdminTesting(object):
 
         def setUp(self):
             self.client = self.on_create_client()
+            fake.seed(random.randint(1000, 10000000))
 
         def test_list(self):
             result = self.client.plugins.list()
@@ -1303,9 +1290,9 @@ class SimulatorConsumerTestCase(KongAdminTesting.ConsumerTestCase):
         return KongAdminSimulator()
 
 
-class SimulatorPluginTestCase(KongAdminTesting.PluginTestCase):
-    def on_create_client(self):
-        return KongAdminSimulator()
+# class SimulatorPluginTestCase(KongAdminTesting.PluginTestCase):
+#     def on_create_client(self):
+#         return KongAdminSimulator()
 
 
 @skipIf(kong_testserver_is_up() is False, 'Kong testserver is down')
@@ -1320,10 +1307,10 @@ class ClientConsumerTestCase(KongAdminTesting.ConsumerTestCase):
         return KongAdminClient(API_URL)
 
 
-@skipIf(kong_testserver_is_up() is False, 'Kong testserver is down')
-class ClientPluginTestCase(KongAdminTesting.PluginTestCase):
-    def on_create_client(self):
-        return KongAdminClient(API_URL)
+# @skipIf(kong_testserver_is_up() is False, 'Kong testserver is down')
+# class ClientPluginTestCase(KongAdminTesting.PluginTestCase):
+#     def on_create_client(self):
+#         return KongAdminClient(API_URL)
 
 
 if __name__ == '__main__':
